@@ -302,7 +302,7 @@ function display_discovery_page() {
 			form_end_row();
 		}
 	} else {
-		print "<tr><td colspan=12><em>" . __('No Devices Found') . "</em></td></tr>";
+		print "<tr class='tableRow'><td colspan='" . (cacti_sizeof($display_text)+1) . "'><em>" . __('No Devices Found') . "</em></td></tr>";
 	}
 
 	html_end_box(false);
