@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,19 +23,22 @@
  +-------------------------------------------------------------------------+
 */
 
-/* do NOT run this script through a web browser */
-if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die('<br><strong>This script is only meant to run at the command line.</strong>');
-}
+require(__DIR__ . '/../include/cli_check.php');
+require_once($config['base_path'] . '/lib/api_automation_tools.php');
+require_once($config['base_path'] . '/lib/api_automation.php');
+require_once($config['base_path'] . '/lib/api_data_source.php');
+require_once($config['base_path'] . '/lib/api_graph.php');
+require_once($config['base_path'] . '/lib/api_device.php');
+require_once($config['base_path'] . '/lib/api_tree.php');
+require_once($config['base_path'] . '/lib/data_query.php');
+require_once($config['base_path'] . '/lib/poller.php');
+require_once($config['base_path'] . '/lib/snmp.php');
+require_once($config['base_path'] . '/lib/sort.php');
+require_once($config['base_path'] . '/lib/template.php');
+require_once($config['base_path'] . '/lib/utility.php');
 
 ini_set('max_execution_time', '0');
 
-$no_http_headers = true;
-
-include(dirname(__FILE__) . '/../include/global.php');
-include_once($config['base_path'] . '/lib/snmp.php');
-include_once($config['base_path'] . '/lib/data_query.php');
-
 /* process calling arguments */
 $parms = $_SERVER['argv'];
 array_shift($parms);
@@ -45,7 +48,7 @@ $host_id	= '';
 $query_id	= 'all';		/* just to mimic the old behaviour */
 $host_descr	= '';
 
-if (sizeof($parms)) {
+if (cacti_sizeof($parms)) {
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
 			list($arg, $value) = explode('=', $parameter);
@@ -75,28 +78,29 @@ if (sizeof($parms)) {
 			case '-V':
 			case '-v':
 				display_version();
+				exit(0);
 			case '--help':
 			case '-H':
 			case '-h':
 				display_help();
-				exit;
+				exit(0);
 			default:
 				print 'ERROR: Invalid Parameter ' . $parameter . "\n\n";
 				display_help();
-				exit;
+				exit(1);
 		}
 	}
 } else {
 	print "ERROR: You must supply input parameters\n\n";
 	display_help();
-	exit;
+	exit(1);
 }
 
 /* determine the hosts to reindex */
 if (strtolower($host_id) == 'all') {
 	$sql_where = '';
 }else if (is_numeric($host_id) && $host_id > 0) {
-	$sql_where = ' WHERE host_id = ' . $host_id;
+	$sql_where = 'WHERE host_id = ' . $host_id;
 } else {
 	print "ERROR: You must specify either a host_id or 'all' to proceed.\n";
 	display_help();
@@ -107,7 +111,7 @@ if (strtolower($host_id) == 'all') {
 if (strtolower($query_id) == 'all') {
 	/* do nothing */
 }else if (is_numeric($query_id) && $query_id > 0) {
-	$sql_where .= ($sql_where != '' ? ' AND snmp_query_id=' . $query_id : ' WHERE snmp_query_id=' . $query_id);
+	$sql_where .= ($sql_where != '' ? ' AND':'WHERE') . ' snmp_query_id=' . $query_id;
 } else {
 	print "ERROR: You must specify either a query_id or 'all' to proceed.\n";
 	display_help();
@@ -116,18 +120,21 @@ if (strtolower($query_id) == 'all') {
 
 /* allow for additional filtering on host description */
 if ($host_descr != '') {
-	$sql_where .= ($sql_where != '' ? " AND host.description like '%" . $host_descr . "%' AND host.id=host_snmp_query.host_id" : " WHERE host.description like '%" . $host_descr . "%' AND host.id=host_snmp_query.host_id");
-	$data_queries = db_fetch_assoc('SELECT host_id, snmp_query_id FROM host_snmp_query,host' . $sql_where);
+	$sql_where .= ($sql_where != '' ? ' AND':'WHERE') . " host.description LIKE '%" . $host_descr . "%' AND host.id=host_snmp_query.host_id";
+
+	$data_queries = db_fetch_assoc('SELECT host_id, snmp_query_id
+		FROM host_snmp_query, host ' . $sql_where);
 } else {
-	$data_queries = db_fetch_assoc('SELECT host_id, snmp_query_id FROM host_snmp_query' . $sql_where);
+	$data_queries = db_fetch_assoc('SELECT host_id, snmp_query_id
+		FROM host_snmp_query ' . $sql_where);
 }
 
 /* issue warnings and start message if applicable */
 print "WARNING: Do not interrupt this script.  Reindexing can take quite some time\n";
-debug("There are '" . sizeof($data_queries) . "' data queries to run");
+debug("There are '" . cacti_sizeof($data_queries) . "' data queries to run");
 
 $i = 1;
-if (sizeof($data_queries)) {
+if (cacti_sizeof($data_queries)) {
 	foreach ($data_queries as $data_query) {
 		if (!$debug) print '.';
 		debug("Data query number '" . $i . "' host: '" . $data_query['host_id'] . "' SNMP Query Id: '" . $data_query['snmp_query_id'] . "' starting");
@@ -137,18 +144,20 @@ if (sizeof($data_queries)) {
 	}
 }
 
+function display_version() {
+	$version = get_cacti_cli_version();
+	print "Cacti Reindex Host Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
+}
+
 /*	display_help - displays the usage of the function */
 function display_help () {
-	$version = get_cacti_version();
-	echo "Reindex Host Utility, Version $version, " . COPYRIGHT_YEARS . "\n\n";
-	echo "usage: poller_reindex_hosts.php --id=[host_id|all] [--qid=[ID|all]] [--host-descr=[description]]\n";
-	echo "                           [-d] [-h] [--help] [-v] [--version]\n\n";
-	echo "--id=host_id             - The host_id to have data queries reindexed or 'all' to reindex all hosts\n";
-	echo "--qid=query_id           - Only index on a specific data query id; defaults to 'all'\n";
-	echo "--host-descr=description - The host description to filter by (SQL filters acknowledged)\n";
-	echo "--debug                  - Display verbose output during execution\n";
-	echo "-v --version             - Display this help message\n";
-	echo "-h --help                - Display this help message\n";
+	display_version();
+	print "usage: poller_reindex_hosts.php --id=[host_id|all] [--qid=[ID|all]]\n";
+	print "   [--host-descr=[description]] [--debug]\n\n";
+	print "--id=host_id             - The host_id to have data queries reindexed or 'all' to reindex all hosts\n";
+	print "--qid=query_id           - Only index on a specific data query id; defaults to 'all'\n";
+	print "--host-descr=description - The host description to filter by (SQL filters acknowledged)\n";
+	print "--debug                  - Display verbose output during execution\n";
 }
 
 function debug($message) {
