@@ -1012,7 +1012,7 @@ function profile() {
 			form_end_row();
 		}
 	} else {
-		print "<tr class='tableRow'><td colspan='4'><em>" . __('No Data Source Profiles Found') . "</em></td></tr>\n";
+		print "<tr class='tableRow'><td colspan='" . (cacti_sizeof($display_text)+1) . "'><em>" . __('No Data Source Profiles Found') . "</em></td></tr>\n";
 	}
 
 	html_end_box(false);
