@@ -144,7 +144,7 @@ case 'view':
 						</tr>
 						<tr>
 							<td class='no-print center'>
-								<strong><?php print html_escape($rra['name']);?></strong>
+								<span><?php print html_escape($rra['name']);?></span>
 							</td>
 						</tr>
 					</table>
@@ -338,7 +338,7 @@ case 'zoom':
 				<tr>
 					<td class='center'>
 						<div class='graphWrapper' id='wrapper_<?php print $graph['local_graph_id']?>' rra_id='<?php print $rra['id'];?>' graph_width='<?php print $graph['width'];?>' graph_height='<?php print $graph['height'];?>' title_font_size='<?php print ((read_user_setting('custom_fonts') == 'on') ? read_user_setting('title_size') : read_config_option('title_size'));?>'></div>
-                            <?php print (read_user_setting('show_graph_title') == 'on' ? "<span class='center'><strong>" . html_escape($graph['title_cache']) . '</strong></span>' : '');?>
+                            <?php print (read_user_setting('show_graph_title') == 'on' ? "<span class='center'>" . html_escape($graph['title_cache']) . '</span>' : '');?>
 					</td>
 					<td id='dd<?php print $graph['local_graph_id'];?>' style='vertical-align:top;' class='graphDrillDown noprint'>
 						<a href='#' id='graph_<?php print $graph['local_graph_id'];?>_properties' class='iconLink properties'>
