@@ -56,7 +56,7 @@ function form_save() {
 		get_filter_request_var('graph_template_input_id');
 		get_filter_request_var('graph_template_id');
 		/* ==================================================== */
-		
+
 		$save['id'] = get_nfilter_request_var('graph_template_input_id');
 		$save['hash'] = get_hash_graph_template(get_nfilter_request_var('graph_template_input_id'), 'graph_template_input');
 		$save['graph_template_id'] = get_nfilter_request_var('graph_template_id');
@@ -75,7 +75,7 @@ function form_save() {
 
 				/* list all select graph items for use down below */
 				foreach ($_POST as $var => $val) {
-					if (preg_match("/^i_(\d+)$/", $var, $matches)) {
+					if (preg_match('/^i_(\d+)$/', $var, $matches)) {
 						/* ================= input validation ================= */
 						input_validate_input_number($matches[1]);
 						/* ==================================================== */
@@ -92,7 +92,7 @@ function form_save() {
 					}
 				}
 
-				if ((isset($new_members)) && (sizeof($new_members) > 0)) {
+				if ((isset($new_members)) && (cacti_sizeof($new_members) > 0)) {
 					foreach ($new_members as $item_id) {
 						push_out_graph_input($graph_template_input_id, $item_id, (isset($new_members) ? $new_members : array()));
 					}
@@ -100,7 +100,7 @@ function form_save() {
 
 				db_execute_prepared('DELETE FROM graph_template_input_defs WHERE graph_template_input_id = ?', array($graph_template_input_id));
 
-				if (sizeof($selected_graph_items) > 0) {
+				if (cacti_sizeof($selected_graph_items) > 0) {
 					foreach ($selected_graph_items as $graph_template_item_id) {
 						db_execute_prepared('INSERT INTO graph_template_input_defs (graph_template_input_id, graph_template_item_id) VALUES (?, ?)', array($graph_template_input_id, $graph_template_item_id));
 					}
@@ -142,7 +142,7 @@ function input_edit() {
 	get_filter_request_var('graph_template_id');
 	/* ==================================================== */
 
-	$header_label = __('Graph Item Inputs [edit graph: %s]', htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM graph_templates WHERE id = ?', array(get_request_var('graph_template_id')))));
+	$header_label = __('Graph Item Inputs [edit graph: %s]', html_escape(db_fetch_cell_prepared('SELECT name FROM graph_templates WHERE id = ?', array(get_request_var('graph_template_id')))));
 
 	/* get a list of all graph item field names and populate an array for user display */
 	foreach ($struct_graph_item as $field_name => $field_array) {
@@ -166,32 +166,37 @@ function input_edit() {
 		)
 	);
 
-	if (!isset_request_var('id')) { 
+	if (!isset_request_var('id')) {
 		set_request_var('id', 0);
 	}
 
 	html_end_box(true, true);
 
 	$item_list = db_fetch_assoc_prepared("SELECT
-		CONCAT_WS(' - ', data_template_data.name, data_template_rrd.data_source_name) AS data_source_name,
-		graph_templates_item.text_format,
-		graph_templates_item.id AS graph_templates_item_id,
-		graph_templates_item.graph_type_id,
-		graph_templates_item.consolidation_function_id,
-		graph_template_input_defs.graph_template_input_id
-		FROM graph_templates_item
-		LEFT JOIN graph_template_input_defs ON (graph_template_input_defs.graph_template_item_id = graph_templates_item.id AND graph_template_input_defs.graph_template_input_id = ?)
-		LEFT JOIN data_template_rrd ON (graph_templates_item.task_item_id = data_template_rrd.id)
-		LEFT JOIN data_local ON (data_template_rrd.local_data_id = data_local.id)
-		LEFT JOIN data_template_data ON (data_local.id = data_template_data.local_data_id)
-		WHERE graph_templates_item.local_graph_id = 0
-		AND graph_templates_item.graph_template_id = ?
-		ORDER BY graph_templates_item.sequence", array(get_request_var('id'), get_request_var('graph_template_id')));
+		CONCAT_WS(' - ', dtd.name, dtr.data_source_name) AS data_source_name,
+		gti.text_format,
+		gti.id AS graph_templates_item_id,
+		gti.graph_type_id,
+		gti.consolidation_function_id,
+		gtid.graph_template_input_id
+		FROM graph_templates_item AS gti
+		LEFT JOIN graph_template_input_defs AS gtid
+		ON gtid.graph_template_item_id = gti.id
+		AND gtid.graph_template_input_id = ?
+		LEFT JOIN data_template_rrd AS dtr
+		ON gti.task_item_id = dtr.id
+		LEFT JOIN data_local AS dl
+		ON dtr.local_data_id = dl.id
+		LEFT JOIN data_template_data AS dtd
+		ON dl.id = dtd.local_data_id
+		WHERE gti.local_graph_id = 0
+		AND gti.graph_template_id = ?
+		ORDER BY gti.sequence", array(get_request_var('id'), get_request_var('graph_template_id')));
 
 	html_start_box(__('Associated Graph Items'), '100%', false, '3', 'center', '');
 
 	$i = 0; $any_selected_item = '';
-	if (sizeof($item_list)) {
+	if (cacti_sizeof($item_list)) {
 		foreach ($item_list as $item) {
 			form_alternate_row();
 
@@ -210,21 +215,21 @@ function input_edit() {
 				$end_bold   = '</strong>';
 			}
 
-			print "<td>";
+			print '<td>';
 
-			$name = "$start_bold Item #" . ($i+1) . ': ' . $graph_item_types[$item['graph_type_id']] . ' (' . $consolidation_functions[$item['consolidation_function_id']] . ")$end_bold";
+			$name = $start_bold . __('Item #%s', $i+1) . ': ' . $graph_item_types[$item['graph_type_id']] . ' (' . $consolidation_functions[$item['consolidation_function_id']] . ')' . $end_bold;
 
-			form_checkbox('i_' . $item['graph_templates_item_id'], $old_value, $name, '', '', get_request_var('graph_template_id')); 
-			print "<label for='i_" . $item['graph_templates_item_id'] . "'>" . $name . "</label>";
+			form_checkbox('i_' . $item['graph_templates_item_id'], $old_value, '', '', '', get_request_var('graph_template_id'));
+			print "<label for='i_" . $item['graph_templates_item_id'] . "'>" . $name . '</label>';
 
-			print "</td>";
+			print '</td>';
 
 			$i++;
 
 			form_end_row();
 		}
 	} else {
-		print "<tr><td><em>" . __('No Items') . "</em></td></tr>";
+		print '<tr><td><em>' . __('No Items') . '</em></td></tr>';
 	}
 
 	form_hidden_box('any_selected_item', $any_selected_item, '');
