@@ -24,7 +24,7 @@
 
 global $current_user;
 
-include('./include/global.php');
+require_once('global.php');
 
 if (!isset($config['cacti_db_version'])) {
 	$version = get_cacti_version();
@@ -33,7 +33,7 @@ if (!isset($config['cacti_db_version'])) {
 	$version = $config['cacti_db_version'];
 }
 
-if ($version != CACTI_VERSION && $config['poller_id'] == 1) {
+if ($version != CACTI_VERSION && $config['poller_id'] == 1 && !defined('IN_CACTI_INSTALL')) {
 	header ('Location: ' . $config['url_path'] . 'install/');
 	exit;
 }
@@ -48,7 +48,7 @@ if (read_config_option('auth_method') != 0) {
 
 	/* handle change password dialog */
 	if ((isset($_SESSION['sess_change_password'])) && (read_config_option('webbasic_enabled') != 'on')) {
-		header ('Location: ' . $config['url_path'] . 'auth_changepassword.php?ref=' . (isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : 'index.php'));
+		header ('Location: ' . $config['url_path'] . 'auth_changepassword.php?ref=' . (isset($_SERVER['HTTP_REFERER']) ? sanitize_uri($_SERVER['HTTP_REFERER']) : 'index.php'));
 		exit;
 	}
 
@@ -61,13 +61,8 @@ if (read_config_option('auth_method') != 0) {
 	}
 
 	/* don't even bother with the guest code if we're already logged in */
-	if ((isset($guest_account)) && (empty($_SESSION['sess_user_id']))) {
-		$guest_user_id = db_fetch_cell_prepared('SELECT id 
-			FROM user_auth 
-			WHERE username = ? 
-			AND realm = 0 
-			AND enabled = "on"', 
-			array(read_config_option('guest_user')));
+	if (isset($guest_account) && empty($_SESSION['sess_user_id'])) {
+		$guest_user_id = get_guest_account();
 
 		/* cannot find guest user */
 		if (!empty($guest_user_id)) {
@@ -78,12 +73,9 @@ if (read_config_option('auth_method') != 0) {
 
 	/* if we are a guest user in a non-guest area, wipe credentials */
 	if (!empty($_SESSION['sess_user_id'])) {
-		$guest_user = db_fetch_cell_prepared('SELECT id 
-			FROM user_auth 
-			WHERE username = ?', 
-			array(read_config_option('guest_user')));
+		$guest_user_id = get_guest_account();
 
-		if (!isset($guest_account) && $guest_user == $_SESSION['sess_user_id']) {
+		if (!isset($guest_account) && $guest_user_id == $_SESSION['sess_user_id']) {
 			kill_session_var('sess_user_id');
 		}
 	}
@@ -100,7 +92,7 @@ if (read_config_option('auth_method') != 0) {
 		} elseif (isset($auth_text) && $auth_text == true) {
 			print __('FATAL: You must be logged in to access this area of Cacti.');
 		} else {
-			include($config['base_path'] . '/auth_login.php');
+			require_once($config['base_path'] . '/auth_login.php');
 		}
 
 		exit;
@@ -111,50 +103,112 @@ if (read_config_option('auth_method') != 0) {
 			$realm_id = $user_auth_realm_filenames[get_current_page()];
 		}
 
+		/* Are we upgrading from a version before 1.2 which has the Install/Upgrade realm 26 */
+		if ($realm_id == 26 && cacti_version_compare(get_cacti_version(), '1.2', '<')) {
+			/* See if we can find any users that are allowed to upgrade */
+			$install_sql_query = '
+					SELECT COUNT(*)
+					FROM (
+						SELECT realm_id
+						FROM user_auth_realm AS uar
+						WHERE uar.realm_id = ?';
+			$install_sql_params = array($realm_id);
+
+			/* See if the group realms exist and if so, check if permission exists there too */
+			if (db_table_exists('user_auth_group_realm')) {
+				$install_sql_query .= '
+						UNION
+						SELECT realm_id
+						FROM user_auth_group_realm AS uagr
+						INNER JOIN user_auth_group_members AS uagm
+						ON uagr.group_id=uagm.group_id
+						INNER JOIN user_auth_group AS uag
+						ON uag.id=uagr.group_id
+						WHERE uag.enabled="on"
+						AND uagr.realm_id = ?';
+				$install_sql_params = array_merge($install_sql_params, array($realm_id));
+			}
+			$install_sql_query .= '
+					) AS authorized';
+			$has_install_user = db_fetch_cell_prepared($install_sql_query, $install_sql_params);
+
+			if (!$has_install_user) {
+				/* We did not find any existing users who can upgrade/install so add any admin *
+				 * who has access to the system settings (realm 15) by default                 */
+				db_execute('INSERT INTO `user_auth_realm` (realm_id, user_id)
+					SELECT 26 as realm_id, ua.id
+					FROM user_auth ua
+					INNER JOIN user_auth_realm uar
+					ON uar.user_id=ua.id
+					LEFT JOIN user_auth_realm uar2
+					ON uar2.user_id=ua.id
+					AND uar2.realm_id=26
+					WHERE uar.realm_id=15
+					AND uar2.user_id IS NULL');
+			}
+		}
+
 		if ($realm_id > 0) {
-			$authorized = db_fetch_cell_prepared('SELECT COUNT(*)
-				FROM (
-					SELECT realm_id
-					FROM user_auth_realm AS uar
-					WHERE uar.user_id = ?
-					AND uar.realm_id = ?
-					UNION
-					SELECT realm_id
-					FROM user_auth_group_realm AS uagr
-					INNER JOIN user_auth_group_members AS uagm
-					ON uagr.group_id=uagm.group_id
-					INNER JOIN user_auth_group AS uag
-					ON uag.id=uagr.group_id
-					WHERE uag.enabled="on"
-					AND uagm.user_id = ?
-					AND uagr.realm_id = ?
-				) AS authorized',
-				array($_SESSION['sess_user_id'], $realm_id, $_SESSION['sess_user_id'], $realm_id));
+			$auth_sql_query = '
+					SELECT COUNT(*)
+					FROM (
+						SELECT realm_id
+						FROM user_auth_realm AS uar
+						WHERE uar.user_id = ?
+						AND uar.realm_id = ?';
+			$auth_sql_params = array($_SESSION['sess_user_id'], $realm_id);
+
+			/* Because we now expect installation to be done by authorized users, check the group_realm *
+			 * exists before using it as this may not be present if upgrading from pre-1.x              */
+			if (db_table_exists('user_auth_group_realm')) {
+				$auth_sql_query .= '
+						UNION
+						SELECT realm_id
+						FROM user_auth_group_realm AS uagr
+						INNER JOIN user_auth_group_members AS uagm
+						ON uagr.group_id=uagm.group_id
+						INNER JOIN user_auth_group AS uag
+						ON uag.id=uagr.group_id
+						WHERE uag.enabled="on"
+						AND uagm.user_id = ?
+						AND uagr.realm_id = ?';
+				$auth_sql_params = array_merge($auth_sql_params, array($_SESSION['sess_user_id'], $realm_id));
+			}
+			$auth_sql_query .= '
+					) AS authorized';
+			$authorized = db_fetch_cell_prepared($auth_sql_query, $auth_sql_params);
 		} else {
 			$authorized = false;
 		}
 
 		if ($realm_id != -1 && !$authorized) {
 			if (isset($_SERVER['HTTP_REFERER'])) {
-				$goBack = "<td colspan='2' align='center'>[<a href='" . htmlspecialchars($_SERVER['HTTP_REFERER']) . "'>" . __('Return') . "</a> | <a href='" . $config['url_path'] . "logout.php'>" . __('Login Again') . "</a>]</td>";
+				$goBack = "<td colspan='2' class='center'>[<a href='" . sanitize_uri($_SERVER['HTTP_REFERER']) . "'>" . __('Return') . "</a> | <a href='" . $config['url_path'] . "logout.php'>" . __('Login Again') . "</a>]</td>";
 			} else {
-				$goBack = "<td colspan='2' align='center'>[<a href='" . $config['url_path'] . "logout.php'>" . __('Login Again') . "</a>]</td>";
+				$goBack = "<td colspan='2' class='center'>[<a href='" . $config['url_path'] . "logout.php'>" . __('Login Again') . "</a>]</td>";
 			}
 
+			$title_header = __('Permission Denied');
+			$title_body = '<p>' . __('You are not permitted to access this section of Cacti.') . '</p><p>' . __('If you feel that this is an error. Please contact your Cacti Administrator.');
+
+			if ($realm_id == 26) {
+				$title_header = __('Installation In Progress');
+				$title_body = '<p>' . __('There is an Installation or Upgrade in progress.') . '</p><p>' . __('Only Cacti Administrators with Install/Upgrade privilege may login at this time') . '</p>';
+			}
 			print "<!DOCTYPE html>\n";
 			print "<html>\n";
 			print "<head>\n";
-			html_common_header(__('Permission Denied'));
+			html_common_header($title_header);
 			print "</head>\n";
 			print "<body class='logoutBody'>
 			<div class='logoutLeft'></div>
 			<div class='logoutCenter'>
 				<div class='logoutArea'>
 					<div class='cactiLogoutLogo'></div>
-					<legend>" . __('Permission Denied') . "</legend>
+					<legend>" . $title_header . "</legend>
 					<div class='logoutTitle'>
-						<p>" . __('You are not permitted to access this section of Cacti.') . '</p><p>' . __('If you feel that this is an error. Please contact your Cacti Administrator.') .
-						"</p>
+						" . $title_body . "
+						</p>
 						<center>" . $goBack . "</center>
 					</div>
 					<div class='logoutErrors'></div>
@@ -168,7 +222,7 @@ if (read_config_option('auth_method') != 0) {
 				$('.loginRight').css('width',parseInt($(window).width()*0.33)+'px');
 			});
 			</script>\n";
-			include_once('./include/global_session.php');
+			include_once('global_session.php');
 			print "</body>
 			</html>\n";
 			exit;
