@@ -295,77 +295,94 @@
 			if ($('#zoom-menu').length == 0) {
 				$('<div id="zoom-menu" class="zoom-menu">'
 					+ '<div class="first_li">'
-					+ 		'<div class="ui-icon ui-icon-zoomin zoomContextMenuAction__zoom_in"></div>'
-					+       '<span class="zoomContextMenuAction__zoom_in">Zoom In</span>'
+					+ 	'<div class="ui-icon ui-icon-zoomin zoomContextMenuAction__zoom_in"></div>'
+					+ 	'<span class="zoomContextMenuAction__zoom_in">' + zoom_i18n_zoom_in + '</span>'
 					+ '</div>'
 					+ '<div class="first_li">'
-					+ 		'<div class="ui-icon ui-icon-zoomout zoomContextMenuAction__zoom_out"></div>'
-					+ 		'<span class="zoomContextMenuAction__zoom_out">Zoom Out (2x)</span>'
-					+ 		'<div class="inner_li">'
-					+ 			'<span class="zoomContextMenuAction__zoom_out__2">2x</span>'
-					+ 			'<span class="zoomContextMenuAction__zoom_out__4">4x</span>'
-					+ 			'<span class="zoomContextMenuAction__zoom_out__8">8x</span>'
-					+ 			'<span class="zoomContextMenuAction__zoom_out__16">16x</span>'
-					+ 			'<span class="zoomContextMenuAction__zoom_out__32">32x</span>'
-					+ 		'</div>'
+					+ 	'<div class="ui-icon ui-icon-zoomout zoomContextMenuAction__zoom_out"></div>'
+					+	'<div class="ui-icon ui-icon-play ui-icon-right"></div>'
+					+ 	'<span class="zoomContextMenuAction__zoom_out">' + zoom_i18n_zoom_out + '</span>'
+					+ 	'<div class="inner_li">'
+					+ 		'<span class="zoomContextMenuAction__zoom_out__2">' + zoom_i18n_zoom_2 + '</span>'
+					+ 		'<span class="zoomContextMenuAction__zoom_out__4">' + zoom_i18n_zoom_4 + '</span>'
+					+ 		'<span class="zoomContextMenuAction__zoom_out__8">' + zoom_i18n_zoom_8 + '</span>'
+					+ 		'<span class="zoomContextMenuAction__zoom_out__16">' + zoom_i18n_zoom_16 + '</span>'
+					+ 		'<span class="zoomContextMenuAction__zoom_out__32">' + zoom_i18n_zoom_32 + '</span>'
+					+ 	'</div>'
 					+ '</div>'
 					+ '<div class="sep_li"></div>'
 					+ '<div class="first_li">'
-					+ 		'<div class="ui-icon ui-icon-empty"></div><span>Zoom Mode</span>'
-					+ 		'<div class="inner_li">'
-					+ 			'<span class="zoomContextMenuAction__set_zoomMode__quick">Quick</span>'
-					+ 			'<span class="zoomContextMenuAction__set_zoomMode__advanced">Advanced</span>'
-					+ 		'</div>'
+					+ 	'<div class="ui-icon ui-icon-empty"></div>'
+					+	'<div class="ui-icon ui-icon-play ui-icon-right"></div>'
+					+	'<span>' + zoom_i18n_mode + '</span>'
+					+ 	'<div class="inner_li">'
+					+ 		'<span class="zoomContextMenuAction__set_zoomMode__quick">' + zoom_i18n_quick + '</span>'
+					+ 		'<span class="zoomContextMenuAction__set_zoomMode__advanced">' + zoom_i18n_advanced + '</span>'
+					+ 	'</div>'
 					+ '</div>'
 					+ '<div class="sep_li"></div>'
 					+ '<div class="first_li">'
-					+ 		'<div class="ui-icon ui-icon-empty"></div><span>Graph</span>'
-					+ 		'<div class="inner_li">'
-					+ 			'<span class="zoomContextMenuAction__newTab">Open in new tab</a></span>'
-					+			'<span class="zoomContextMenuAction__save">Save graph</span>'
-					+ 			'<span class="zoomContextMenuAction__link">Copy graph link</span>'
-					+ 		'</div>'
+					+ 	'<div class="ui-icon ui-icon-empty"></div>'
+					+	'<div class="ui-icon ui-icon-play ui-icon-right"></div>'
+					+	'<span>' + zoom_i18n_graph + '</span>'
+					+	'<div class="inner_li">'
+					+ 		'<span class="zoomContextMenuAction__newTab">' + zoom_i18n_newTab + '</span>'
+					+		'<span class="zoomContextMenuAction__save">' + zoom_i18n_save_graph + '</span>'
+					+		'<span class="zoomContextMenuAction__copy">' + zoom_i18n_copy_graph + '</span>'
+					+		'<span class="zoomContextMenuAction__link">' + zoom_i18n_copy_graph_link + '</span>'
+					+	'</div>'
 					+ '</div>'
 					+ '<div class="first_li">'
-					+ 		'<div class="ui-icon ui-icon-wrench"></div><span>Settings</span>'
+					+	'<div class="ui-icon ui-icon-wrench"></div>'
+					+	'<div class="ui-icon ui-icon-play ui-icon-right"></div>'
+					+	'<span>' + zoom_i18n_settings + '</span>'
+					+	'<div class="inner_li">'
+					+		'<div class="sec_li">'
+					+			'<div class="ui-icon ui-icon-play ui-icon-right"></div>'
+					+			'<span>' + zoom_i18n_timestamps + '</span>'
+					+			'<div class="inner_li">'
+					+ 				'<span class="zoomContextMenuAction__set_zoomTimestamps__on">' + zoom_i18n_on + '</span>'
+					+ 				'<span class="zoomContextMenuAction__set_zoomTimestamps__auto">' + zoom_i18n_auto + '</span>'
+					+ 				'<span class="zoomContextMenuAction__set_zoomTimestamps__off">' + zoom_i18n_off + '</span>'
+					+ 			'</div>'
+					+ 		'</div>'
+					+ 		'<div class="sep_li"></div>'
+					+ 		'<div class="sec_li">'
+					+			'<div class="ui-icon ui-icon-play ui-icon-right"></div>'
+					+			'<span>' + zoom_i18n_zoom_out_factor + '</span>'
 					+ 			'<div class="inner_li">'
-					+ 				'<div class="sec_li advanced_mode"><span>Timestamps</span></span>'
-					+ 					'<div class="inner_li advanced_mode">'
-					+ 						'<span class="zoomContextMenuAction__set_zoomTimestamps__on">Always On</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoomTimestamps__auto">Auto</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoomTimestamps__off">Always Off</span>'
-					+ 					'</div>'
+					+ 				'<span class="zoomContextMenuAction__set_zoomOutFactor__2">' + zoom_i18n_zoom_2 + '</span>'
+					+ 				'<span class="zoomContextMenuAction__set_zoomOutFactor__4">' + zoom_i18n_zoom_4 + '</span>'
+					+ 				'<span class="zoomContextMenuAction__set_zoomOutFactor__8">' + zoom_i18n_zoom_8 + '</span>'
+					+ 				'<span class="zoomContextMenuAction__set_zoomOutFactor__16">' + zoom_i18n_zoom_16 + '</span>'
+					+ 				'<span class="zoomContextMenuAction__set_zoomOutFactor__32">' + zoom_i18n_zoom_32 + '</span>'
+					+ 			'</div>'
+					+ 		'</div>'
+					+ 		'<div class="sec_li">'
+					+			'<div class="ui-icon ui-icon-play ui-icon-right"></div>'
+					+			'<span>' + zoom_i18n_zoom_out_positioning + '</span>'
+					+ 				'<div class="inner_li">'
+					+ 					'<span class="zoomContextMenuAction__set_zoomOutPositioning__begin">' + zoom_i18n_begin + '</span>'
+					+ 					'<span class="zoomContextMenuAction__set_zoomOutPositioning__center">' + zoom_i18n_center + '</span>'
+					+ 					'<span class="zoomContextMenuAction__set_zoomOutPositioning__end">' + zoom_i18n_end + '</span>'
 					+ 				'</div>'
-					+ 				'<div class="sep_li"></div>'
-					+ 				'<div class="sec_li"><span>Zoom Out Factor</span>'
-					+ 					'<div class="inner_li">'
-					+ 						'<span class="zoomContextMenuAction__set_zoomOutFactor__2">2x</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoomOutFactor__4">4x</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoomOutFactor__8">8x</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoomOutFactor__16">16x</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoomOutFactor__32">32x</span>'
-					+ 					'</div>'
-					+ 				'</div>'
-					+ 				'<div class="sec_li"><span>Zoom Out Positioning</span>'
-					+ 					'<div class="inner_li">'
-					+ 						'<span class="zoomContextMenuAction__set_zoomOutPositioning__begin">Begin with</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoomOutPositioning__center">Center</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoomOutPositioning__end">End with</span>'
-					+ 					'</div>'
-					+ 				'</div>'
-					+ 				'<div class="sec_li"><span>3rd Mouse Button</span>'
-					+ 					'<div class="inner_li">'
-					+ 						'<span class="zoomContextMenuAction__set_zoom3rdMouseButton__zoom_in">Zoom in</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoom3rdMouseButton__zoom_out">Zoom out</span>'
-					+ 						'<span class="zoomContextMenuAction__set_zoom3rdMouseButton__off">Disabled</span>'
-					+ 					'</div>'
+					+ 			'</div>'
+					+ 			'<div class="sec_li">'
+					+				'<div class="ui-icon ui-icon-play ui-icon-right"></div>'
+					+				'<span>' + zoom_i18n_3rd_button + '</span>'
+					+ 				'<div class="inner_li">'
+					+ 					'<span class="zoomContextMenuAction__set_zoom3rdMouseButton__zoom_in">' + zoom_i18n_zoom_in + '</span>'
+					+ 					'<span class="zoomContextMenuAction__set_zoom3rdMouseButton__zoom_out">' + zoom_i18n_zoom_out + '</span>'
+					+ 					'<span class="zoomContextMenuAction__set_zoom3rdMouseButton__off">' + zoom_i18n_disabled + '</span>'
 					+ 				'</div>'
 					+ 			'</div>'
 					+ 		'</div>'
+					+ 	'</div>'
 					+ '<div class="sep_li"></div>'
 					+ '<div class="first_li">'
-					+ 		'<div class="ui-icon ui-icon-close zoomContextMenuAction__close"></div><span class="zoomContextMenuAction__close">Close</span>'
-				+ '</div>').appendTo('body');
+					+ 	'<div class="ui-icon ui-icon-close zoomContextMenuAction__close"></div>'
+					+	'<span class="zoomContextMenuAction__close">' + zoom_i18n_close + '</span>'
+					+ '</div>').appendTo('body');
 			}
 			zoomElements_reposition();
 			zoomElements_reset();
@@ -688,7 +705,7 @@
 				$('#' + zoom.options.inputfieldEndTime).val(unixTime2Date(newGraphEndTime));
 
 				if (graph_start !== null && graph_end !== null) {
-					if (myGraphLocation != 'graph') {
+					if (pageAction != 'graph') {
 						graph_start = newGraphStartTime;
 						graph_end = newGraphEndTime;
 
@@ -725,6 +742,10 @@
 			}
 		}
 
+		function getZoomOutFactorText(zoomOutFactor) {
+			return eval('zoom_i18n_zoom_out + \' (\' + zoom_i18n_zoom_' + zoomOutFactor + ' + \')\'');
+		}
+
 		/*
 		* executes a static zoom out (as right click event)
 		*/
@@ -791,7 +812,7 @@
 				$('#' + zoom.options.inputfieldEndTime).val(unixTime2Date(newGraphEndTime));
 
 				if (graph_start !== null && graph_end !== null) {
-					if (myGraphLocation != 'graph') {
+					if (pageAction != 'graph') {
 						graph_start = newGraphStartTime;
 						graph_end = newGraphEndTime;
 
@@ -860,7 +881,7 @@
 			$('.zoomContextMenuAction__set_zoomOutFactor__' + zoom.custom.zoomOutFactor).addClass('zoom-menu-highlight');
 			$('.zoomContextMenuAction__set_zoomOutPositioning__' + zoom.custom.zoomOutPositioning).addClass('zoom-menu-highlight');
 			$('.zoomContextMenuAction__set_zoom3rdMouseButton__' + ((zoom.custom.zoom3rdMouseButton === false) ? 'off' : zoom.custom.zoom3rdMouseButton) ).addClass('zoom-menu-highlight');
-			$('.zoomContextMenuAction__zoom_out').text('Zoom Out (' + zoom.custom.zoomOutFactor + 'x)');
+			$('.zoomContextMenuAction__zoom_out').text(getZoomOutFactorText(zoom.custom.zoomOutFactor));
 
 			if (zoom.custom.zoomMode == 'quick') {
 				$('.advanced_mode').hide();
@@ -900,7 +921,7 @@
 			$('.first_li , .sec_li, .inner_li span').hover(
 				function () {
 					$(this).addClass('zoom-menu-hover');
-					if ( $(this).children().size() >0 )
+					if ( $(this).children().length >0 )
 						if (zoom.custom.zoomMode == 'quick') {
 							$(this).children('.inner_li:not(.advanced_mode)').show();
 						} else {
@@ -965,7 +986,7 @@
 						storage.set(zoom.options.cookieName, serialize(zoom.custom));
 						$('[class*=zoomContextMenuAction__set_zoomOutFactor__]').removeClass('zoom-menu-highlight');
 						$('.zoomContextMenuAction__set_zoomOutFactor__' + value).addClass('zoom-menu-highlight');
-						$('.zoomContextMenuAction__zoom_out').text('Zoom Out (' + value + 'x)');
+						$('.zoomContextMenuAction__zoom_out').text(getZoomOutFactorText(value));
 					}
 					break;
 				case 'outpositioning':
@@ -1001,6 +1022,16 @@
 				case 'zoom_in':
 					zoomAction_zoom_in();
 					break;
+				case 'copy':
+					$('#zoom-textarea').html('<img src="data:image/png;base64,'+btoa(unescape(encodeURIComponent(zoom.image.data)))+'" width="'+zoom.image.width+'" height="'+zoom.image.height+'">').select();
+
+					try {
+						var successful = document.execCommand('copy');
+					} catch (err) {
+						alert('Unsupported Browser');
+					}
+					return false;
+					break;
 				case 'save':
 					var arraybuffer = new ArrayBuffer(zoom.image.data.length);
 					var view = new Uint8Array(arraybuffer);
