@@ -22,16 +22,28 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_0_8_6h() {
-	/* changes for ping result times */
-	db_install_execute("ALTER TABLE `host` MODIFY COLUMN `min_time` DECIMAL(10,5) DEFAULT 9.99999;");
-	db_install_execute("ALTER TABLE `host` MODIFY COLUMN `max_time` DECIMAL(10,5) DEFAULT 0.00000;");
-	db_install_execute("ALTER TABLE `host` MODIFY COLUMN `cur_time` DECIMAL(10,5) DEFAULT 0.00000;");
-	db_install_execute("ALTER TABLE `host` MODIFY COLUMN `avg_time` DECIMAL(10,5) DEFAULT 0.00000;");
+function upgrade_to_0_8_7h() {
+	global $config;
 
-	/* Changes to user_log */
-	db_install_execute("ALTER TABLE `user_log` MODIFY COLUMN `ip` VARCHAR(40);");
+	require_once($config["base_path"] . "/lib/poller.php");
 
-	/* Fixes broken graphs that have graph items with legend text but no color assigned */
-	db_install_execute("UPDATE graph_templates_item SET text_format = '' WHERE local_graph_id <> 0 AND color_id = 0 AND graph_type_id IN(4,5,6,7,8) AND text_format <> '';");
+	/* speed up the reindexing */
+	db_install_add_column('host_snmp_cache', array('name' => 'present', 'type' => 'tinyint', 'NULL' => false, 'default' => '1', 'after' => 'oid'));
+	db_install_add_key('host_snmp_cache', 'index', 'present', array('present'));
+
+	db_install_add_column('poller_item', array('name' => 'present', 'type' => 'tinyint', 'NULL' => false, 'default' => '1', 'after' => 'action'));
+	db_install_add_key('poller_item', 'index', 'present', array('present'));
+
+	db_install_add_column('poller_reindex', array('name' => 'present', 'type' => 'tinyint', 'NULL' => false, 'default' => '1', 'after' => 'action'));
+	db_install_add_key('poller_reindex', 'index', 'present', array('present'));
+
+	db_install_add_column('host', array('name' => 'device_threads', 'type' => 'tinyint(2) unsigned', 'NULL' => false, 'default' => '1', 'after' => 'max_oids'));
+
+	db_install_add_key('data_template_rrd', 'unique index',  'duplicate_dsname_contraint', array('local_data_id', 'data_source_name', 'data_template_id'));
+
+	/* update the reindex cache, as we now introduced more options for "index count changed" */
+	$command_string = read_config_option("path_php_binary");
+	$extra_args = "-q \"" . $config["base_path"] . "/cli/poller_reindex_hosts.php\" --id=all";
+	exec_background($command_string, "$extra_args");
+	cacti_log(__FUNCTION__ . " running $command_string $extra_args", false, "UPGRADE");
 }
