@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -32,7 +32,7 @@ function aggregate_build_children_url($local_graph_id, $graph_start = -1, $graph
 		WHERE local_graph_id = ?',
 		array($local_graph_id));
 
-	if (sizeof($aggregate_data)) {
+	if (cacti_sizeof($aggregate_data)) {
 		$local_graph_ids = array_rekey(
 			db_fetch_assoc_prepared('SELECT local_graph_id
 				FROM aggregate_graphs_items
@@ -41,14 +41,14 @@ function aggregate_build_children_url($local_graph_id, $graph_start = -1, $graph
 			), 'local_graph_id', 'local_graph_id'
 		);
 
-		if (sizeof($local_graph_ids)) {
+		if (cacti_sizeof($local_graph_ids)) {
 			$graph_select = 'graph_add=';
 
 			foreach($local_graph_ids as $graph) {
 				$graph_select .= $graph . '%2C';
 			}
 
-			return "<a class='hyperLink aggregates' href='" . htmlspecialchars($config['url_path'] . 'graph_view.php?page=1&graph_template_id=0&host_id=-1&filter=&style=selective&action=preview' . ($graph_start >= 0 ? '&graph_start=' . $graph_start:'') . ($graph_end >= 0 ? '&graph_end=' . $graph_end:'') . ($rra_id >= 0 ? '&rra_id=' . $rra_id:'') . '&' . $graph_select) . "'><img src='" . $config['url_path'] . "images/view_aggregate_children.png' alt='' title='" . __esc('Display Graphs from this Aggregate') . "'></a><br/>\n";
+			return "<a class='hyperLink aggregates' href='" . html_escape($config['url_path'] . 'graph_view.php?page=1&graph_template_id=0&host_id=-1&filter=&style=selective&action=preview' . ($graph_start >= 0 ? '&graph_start=' . $graph_start:'') . ($graph_end >= 0 ? '&graph_end=' . $graph_end:'') . ($rra_id >= 0 ? '&rra_id=' . $rra_id:'') . '&' . $graph_select) . "'><img src='" . $config['url_path'] . "images/view_aggregate_children.png' alt='' title='" . __esc('Display Graphs from this Aggregate') . "'></a><br/>" . PHP_EOL;
 		}
 	}
 }
@@ -61,6 +61,7 @@ function api_aggregate_convert_template($graphs) {
 		array($aggregate_template_id));
 
 	foreach($graphs as $graph) {
+		$save                          = array();
 		$save['id']                    = '';
 		$save['local_graph_id']        = $graph;
 		$save['aggregate_template_id'] = $aggregate_template_id;
@@ -200,7 +201,7 @@ function api_aggregate_create($aggregate_name, $graphs, $agg_template_id = 0) {
 		}
 	}
 
-	if (sizeof($agg_template)) {
+	if (cacti_sizeof($agg_template)) {
 		/* create new graph in cacti tables */
 		$graph_template_graph = db_fetch_row_prepared('SELECT *
 			FROM graph_templates_graph
@@ -220,7 +221,7 @@ function api_aggregate_create($aggregate_name, $graphs, $agg_template_id = 0) {
 
 		$agg_id = sql_save($save, 'aggregate_graphs');
 
-		if (sizeof($graph_items)) {
+		if (cacti_sizeof($graph_items)) {
 			$aggs = 1;
 			$sql  = '';
 			foreach($graph_items as $i) {
@@ -295,7 +296,7 @@ function aggregate_error_handler($errno, $errmsg, $filename, $linenum, $vars) {
 		cacti_debug_backtrace('AGGREGATE', true);
 
 		if (isset($GLOBALS['error_fatal'])) {
-			if($GLOBALS['error_fatal'] & $errno) die('fatal');
+			if($GLOBALS['error_fatal'] & $errno) die("Fatal error $errno" . PHP_EOL);
 		}
 	}
 
@@ -579,6 +580,8 @@ function duplicate_color_template($_color_template_id, $color_template_title) {
 		WHERE color_template_id = ?',
 		array($_color_template_id));
 
+	$save = array();
+
 	/* create new entry: color_templates */
 	$save['color_template_id'] = 0;
 
@@ -589,11 +592,10 @@ function duplicate_color_template($_color_template_id, $color_template_title) {
 
 	$new_color_template_id = sql_save($save, 'color_templates', 'color_template_id');
 
-	unset($save);
-
 	/* create new entry(s): color_template_items */
-	if (sizeof($color_template_items)) {
+	if (cacti_sizeof($color_template_items)) {
 		foreach ($color_template_items as $color_template_item) {
+			$save = array();
 			$save['color_template_item_id'] = 0;
 			$save['color_template_id'] = $new_color_template_id;
 			$save['color_id'] = $color_template_item['color_id'];
@@ -602,7 +604,6 @@ function duplicate_color_template($_color_template_id, $color_template_title) {
 			cacti_log(__FUNCTION__ . ' called. Id:' . $new_color_template_id . ' Color: ' . $save['color_id'] . ' sequence: ' . $save['sequence'], true, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 
 			$new_color_template_item_id = sql_save($save, 'color_template_items', 'color_template_item_id');
-			unset($save);
 		}
 	}
 }
@@ -631,6 +632,7 @@ function aggregate_cdef_make0() {
 	}
 
 	# create a new cdef entry
+	$save           = array();
 	$save['id']     = 0;
 	$save['hash']   = get_hash_cdef(0);
 	$save['system'] = 1;
@@ -642,7 +644,7 @@ function aggregate_cdef_make0() {
 	cacti_log(__FUNCTION__ . ' created new cdef: ' . $new_cdef_id . ' name: ' . $magic, true, 'AGGREGATE', POLLER_VERBOSITY_DEEBUG);
 
 	# create a new cdef item entry
-	unset($save);
+	$save             = array();
 	$save['id']       = 0;
 	$save['hash']     = get_hash_cdef(0, 'cdef_item');
 	$save['cdef_id']  = $new_cdef_id;
@@ -706,7 +708,7 @@ function aggregate_cdef_totalling($_new_graph_id, $_graph_item_sequence, $_total
 	$cdefs[0]['cdef_text'] = 'CURRENT_DATA_SOURCE';
 
 	/* new CDEF(s) are required! */
-	$num_items = sizeof($graph_template_items);
+	$num_items = cacti_sizeof($graph_template_items);
 	if ($num_items > 0) {
 		$i = 0;
 		foreach ($graph_template_items as $graph_template_item) {
@@ -744,6 +746,7 @@ function aggregate_cdef_totalling($_new_graph_id, $_graph_item_sequence, $_total
 			# in case, we have NO match
 			if (empty($new_cdef_id)) {
 				# create a new cdef entry
+				$save           = array();
 				$save['id']     = 0;
 				$save['hash']   = get_hash_cdef(0);
 				$save['system'] = 1;
@@ -764,9 +767,9 @@ function aggregate_cdef_totalling($_new_graph_id, $_graph_item_sequence, $_total
 				$new_cdef_id  = sql_save($save, 'cdef');
 
 				cacti_log(__FUNCTION__ . ' created new cdef: ' . $new_cdef_id . ' name: ' . $new_cdef_name . ' value: ' . $new_cdef_text, true, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
-				unset($save);
 
 				# create a new cdef item entry
+				$save             = array();
 				$save['id']       = 0;
 				$save['hash']     = get_hash_cdef(0, 'cdef_item');
 				$save['cdef_id']  = $new_cdef_id;
@@ -807,8 +810,8 @@ function aggregate_cdef_totalling($_new_graph_id, $_graph_item_sequence, $_total
 function auto_hr($s, $h) {
 	cacti_log(__FUNCTION__ . ' called', true, 'AGGREGATE', POLLER_VERBOSITY_DEVDBG);
 
-	# start at end of array, both arrays are from 1 .. count(array)
-	$i = count($h);
+	# start at end of array, both arrays are from 1 .. cacti_count(array)
+	$i = cacti_count($h);
 
 	# make sure, that last item always has a HR, even if template does not have any
 	$h[$i] = true;
@@ -860,7 +863,7 @@ function api_aggregate_remove_multi($graphs) {
 
 	include_once($config['base_path'] . '/lib/api_graph.php');
 
-	if (sizeof($graphs)) {
+	if (cacti_sizeof($graphs)) {
 		foreach($graphs as $graph) {
 			$ag = db_fetch_cell_prepared('SELECT id
 				FROM aggregate_graphs
@@ -909,12 +912,12 @@ function aggregate_prune_graphs($local_graph_id = 0) {
 		$aggregate_graphs[$p['aggregate_graph_id']] = $p['aggregate_graph_id'];
 	}
 
-	if (sizeof($local_graph_ids)) {
+	if (cacti_sizeof($local_graph_ids)) {
 		db_execute('DELETE FROM aggregate_graphs_items
 			WHERE local_graph_id IN (' . implode(',', $local_graph_ids) . ')');
 	}
 
-	if (sizeof($aggregate_graphs) || $local_graph_id > 0) {
+	if (cacti_sizeof($aggregate_graphs) || $local_graph_id > 0) {
 		if ($local_graph_id > 0) {
 			$agg_graph = db_fetch_cell_prepared('SELECT id
 				FROM aggregate_graphs
@@ -941,7 +944,7 @@ function aggregate_prune_graphs($local_graph_id = 0) {
 				AND dtr.id IS NULL
 				AND gti.graph_type_id IN (4,5,6,7,8,9)', array($graph_id)), 'id', 'id');
 
-			if (sizeof($bad_graph_items)) {
+			if (cacti_sizeof($bad_graph_items)) {
 				db_execute('DELETE FROM graph_templates_item
 					WHERE id IN (' . implode(',', $bad_graph_items) . ')');
 			}
