@@ -27,7 +27,7 @@ function getHostTemplates() {
 
 	$host_templates[0] = 'None';
 
-	if (sizeof($tmpArray)) {
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $template) {
 			$host_templates[$template['id']] = $template['name'];
 		}
@@ -36,11 +36,35 @@ function getHostTemplates() {
 	return $host_templates;
 }
 
-function getHostsByDescription() {
+function getHostsByDescription($hostTemplateIds = false) {
 	$hosts = array();
-	$tmpArray = db_fetch_assoc('SELECT id, description FROM host ORDER BY description');
 
-	if (sizeof($tmpArray)) {
+	if ($hostTemplateIds !== false) {
+		if (!is_array($hostTemplateIds)) {
+			$hostTemplateIds = array($hostTemplateIds);
+		}
+	}
+
+	if ($hostTemplateIds !== false && cacti_sizeof($hostTemplateIds)) {
+		foreach($hostTemplateIds as $id) {
+			if (!is_numeric($id)) {
+				return false;
+			}
+		}
+
+		$sql_where = 'WHERE ht.id IN (' . implode(',', $hostTemplateIds) . ')';
+	} else {
+		$sql_where = '';
+	}
+
+	$tmpArray = db_fetch_assoc("SELECT h.id, h.description 
+		FROM host AS h
+		INNER JOIN host_template AS ht
+		ON h.host_template_id = h.id
+		$sql_where
+		ORDER BY h.description");
+
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $tmp) {
 			$hosts[$tmp['description']] = $tmp['id'];
 		}
@@ -49,11 +73,48 @@ function getHostsByDescription() {
 	return $hosts;
 }
 
-function getHosts() {
-	$hosts    = array();
-	$tmpArray = db_fetch_assoc('SELECT * FROM host ORDER BY id');
+function getSites() {
+	$sites = array();
+	$tmpArray = db_fetch_assoc('SELECT * FROM sites ORDER BY id');
 
-	if (sizeof($tmpArray)) {
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
+		foreach ($tmpArray as $site) {
+			$sites[$site['id']] = $site;
+		}
+	}
+
+	return $sites;
+}
+
+function getHosts($hostTemplateIds = false) {
+	$hosts = array();
+
+	if ($hostTemplateIds !== false) {
+		if (!is_array($hostTemplateIds)) {
+			$hostTemplateIds = array($hostTemplateIds);
+		}
+	}
+
+	if ($hostTemplateIds !== false && cacti_sizeof($hostTemplateIds)) {
+		foreach($hostTemplateIds as $id) {
+			if (!is_numeric($id)) {
+				return false;
+			}
+		}
+
+		$sql_where = 'WHERE ht.id IN (' . implode(',', $hostTemplateIds) . ')';
+	} else {
+		$sql_where = '';
+	}
+
+	$tmpArray = db_fetch_assoc("SELECT h.id, h.hostname, h.description, h.host_template_id
+		FROM host AS h
+		LEFT JOIN host_template AS ht
+		ON h.host_template_id = ht.id
+		$sql_where
+		ORDER BY h.id");
+
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $host) {
 			$hosts[$host['id']] = $host;
 		}
@@ -63,7 +124,7 @@ function getHosts() {
 }
 
 function getInputFields($templateId) {
-	$fields    = array();
+	$fields = array();
 
 	$tmpArray = db_fetch_assoc_prepared("SELECT DISTINCT dif.data_name AS `name`, dif.name AS `description`,
 		did.value AS `default`, dtd.data_template_id, dif.id AS `data_input_field_id`
@@ -86,7 +147,7 @@ function getInputFields($templateId) {
 		AND dif.input_output IN ('in', 'inout')",
 		array($templateId));
 
-	if (sizeof($tmpArray)) {
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $row) {
 			$fields[$row['data_template_id'] . ':' . $row['name']] = $row;
 		}
@@ -99,7 +160,7 @@ function getAddresses() {
 	$addresses = array();
 	$tmpArray  = db_fetch_assoc('SELECT id, hostname FROM host ORDER BY hostname');
 
-	if (sizeof($tmpArray)) {
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $tmp) {
 			$addresses[$tmp['hostname']] = $tmp['id'];
 		}
@@ -123,7 +184,7 @@ function getSNMPFields($hostId, $snmp_query_id = '') {
 		$sql_where
 		ORDER BY field_name");
 
-	if (sizeof($tmpArray)) {
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $f) {
 			$fieldNames[$f['field_name']] = 1;
 		}
@@ -148,7 +209,7 @@ function getSNMPValues($hostId, $field, $snmp_query_id = '') {
 		$sql_where
 		ORDER BY field_value");
 
-	if (sizeof($tmpArray)) {
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $v) {
 			$values[$v['field_value']] = 1;
 		}
@@ -161,7 +222,7 @@ function getSNMPQueries() {
 	$queries  = array();
 	$tmpArray = db_fetch_assoc('SELECT id, name FROM snmp_query ORDER by id');
 
-	if (sizeof($tmpArray)) {
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $q) {
 			$queries[$q['id']] = $q['name'];
 		}
@@ -172,9 +233,14 @@ function getSNMPQueries() {
 
 function getSNMPQueryTypes($snmpQueryId) {
 	$types    = array();
-	$tmpArray = db_fetch_assoc_prepared('SELECT id, name FROM snmp_query_graph WHERE snmp_query_id = ? ORDER BY id', array($snmpQueryId));
 
-	if (sizeof($tmpArray)) {
+	$tmpArray = db_fetch_assoc_prepared('SELECT id, name 
+		FROM snmp_query_graph 
+		WHERE snmp_query_id = ? 
+		ORDER BY id', 
+		array($snmpQueryId));
+
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $type) {
 			$types[$type['id']] = $type['name'];
 		}
@@ -185,9 +251,10 @@ function getSNMPQueryTypes($snmpQueryId) {
 
 function getGraphTemplates() {
 	$graph_templates = array();
-	$tmpArray        = db_fetch_assoc('SELECT id, name FROM graph_templates ORDER BY id');
 
-	if (sizeof($tmpArray)) {
+	$tmpArray = db_fetch_assoc('SELECT id, name FROM graph_templates ORDER BY id');
+
+	if ($tmpArray !== false && cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $t) {
 			$graph_templates[$t['id']] = $t['name'];
 		}
@@ -196,15 +263,35 @@ function getGraphTemplates() {
 	return $graph_templates;
 }
 
-function getGraphTemplatesByHostTemplate($host_template_id) {
+function getGraphTemplatesByHostTemplate($host_template_ids = false) {
 	$graph_templates = array();
-	$tmpArray 		 = db_fetch_assoc_prepared('SELECT host_template_graph.graph_template_id AS id, graph_templates.name AS name
-						FROM host_template_graph
-						LEFT JOIN graph_templates
-						ON (host_template_graph.graph_template_id = graph_templates.id)
-						WHERE host_template_id = ?', array($host_template_id));
 
-	if (sizeof($tmpArray)) {
+	if ($host_template_ids !== false) {
+		if (!is_array($host_template_ids)) {
+			$host_template_ids = array($host_template_ids);
+		}
+	}
+
+	if ($host_template_ids !== false && cacti_sizeof($host_template_ids)) {
+		foreach($host_template_ids as $id) {
+			if (!is_numeric($id)) {
+				return false;
+			}
+		}
+
+		$sql_where = 'WHERE htg.host_template_id IN (' . implode(',', $host_template_ids) . ')';
+	} else {
+		$sql_where = '';
+	}
+
+	$tmpArray = db_fetch_assoc_prepared("SELECT htg.graph_template_id AS id, gt.name AS name
+		FROM host_template_graph AS htg
+		LEFT JOIN graph_templates AS gt
+		ON htg.graph_template_id = gt.id
+		$sql_where
+		ORDER by gt.name ASC");
+
+	if (cacti_sizeof($tmpArray)) {
 		foreach ($tmpArray as $t) {
 			$graph_templates[$t['id']] = $t['name'];
 		}
@@ -215,137 +302,165 @@ function getGraphTemplatesByHostTemplate($host_template_id) {
 
 function displayQueryTypes($types, $quietMode = false) {
 	if (!$quietMode) {
-		echo "Known SNMP Query Types: (id, name)\n";
+		print 'Known SNMP Query Types: (id, name)' . PHP_EOL;
 	}
 
-	foreach ($types as $id => $name) {
-		echo $id . "\t" . $name . "\n";
+	if ($types !== false && cacti_sizeof($types)) {
+		foreach ($types as $id => $name) {
+			print $id . "\t" . $name . PHP_EOL;
+		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displayHostTemplates($host_templates, $quietMode = false) {
 	if (!$quietMode) {
-		echo "Valid Device Templates: (id, name)\n";
+		print 'Valid Device Templates: (id, name)' . PHP_EOL;
 	}
 
-	if (sizeof($host_templates)) {
+	if ($host_templates !== false && cacti_sizeof($host_templates)) {
 		foreach ($host_templates as $id => $name) {
-			echo "$id\t$name\n";
+			print "$id\t$name" . PHP_EOL;
 		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displayCommunities($quietMode = false) {
 	if (!$quietMode) {
-		echo "Known communities are: (community)\n";
+		print 'Known SNMP Communities: (community)' . PHP_EOL;
 	}
 
-	$communities = db_fetch_assoc('SELECT DISTINCT snmp_community FROM host ORDER BY snmp_community');
+	$communities = db_fetch_assoc('SELECT DISTINCT snmp_community 
+		FROM host 
+		ORDER BY snmp_community');
 
-	if (sizeof($communities)) {
+	if ($communities !== false &&cacti_sizeof($communities)) {
 		foreach ($communities as $community) {
-			echo $community['snmp_community']."\n";
+			print $community['snmp_community'] . PHP_EOL;
 		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displaySNMPFields($fields, $hostId, $quietMode = false) {
 	if (!$quietMode) {
-		echo "Known SNMP Fields for host-id $hostId: (name)\n";
+		print 'Known SNMP Fields for host-id ' . $hostId . ': (name)' . PHP_EOL;
 	}
 
-	foreach ($fields as $field => $values) {
-		echo $field . "\n";
+	if ($fields !== false && cacti_sizeof($fields)) {
+		foreach ($fields as $field => $values) {
+			print $field . PHP_EOL;
+		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displaySNMPValues($values, $hostId, $field, $quietMode = false) {
 	if (!$quietMode) {
-		echo "Known values for $field for host $hostId: (name)\n";
+		print 'Known SNMP Values for Field ' . $field . ' and host-id ' . $hostId . ': (name)' . PHP_EOL;
 	}
 
-	foreach ($values as $value => $foo) {
-		echo "$value\n";
+	if ($values !== false && cacti_sizeof($values)) {
+		foreach ($values as $value => $foo) {
+			print $value . PHP_EOL;
+		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displaySNMPQueries($queries, $quietMode = false) {
 	if (!$quietMode) {
-		echo "Known SNMP Queries:(id, name)\n";
+		print 'Known SNMP Queries: (id, name)' . PHP_EOL;
 	}
 
-	foreach ($queries as $id => $name) {
-		echo $id . "\t" . $name . "\n";
+	if ($queries !== false &&cacti_sizeof($queries)) {
+		foreach ($queries as $id => $name) {
+			print $id . "\t" . $name . PHP_EOL;
+		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displayInputFields($input_fields, $quietMode = false) {
 	if (!$quietMode) {
-		echo "Known Input Fields:(name, default, description)\n";
+		print 'Known Input Fields: (name, default, description)' . PHP_EOL;
 	}
 
-	if (sizeof($input_fields)) {
-	foreach ($input_fields as $row) {
-		echo $row['data_template_id'] . ':' . $row['name'] . "\t" . $row['default'] . "\t" . $row['description'] . "\n";
-	}
+	if ($input_fields !== false &&cacti_sizeof($input_fields)) {
+		foreach ($input_fields as $row) {
+			print $row['data_template_id'] . ':' . $row['name'] . "\t" . $row['default'] . "\t" . $row['description'] . PHP_EOL;
+		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displayGraphTemplates($templates, $quietMode = false) {
 	if (!$quietMode) {
-		echo "Known Graph Templates:(id, name)\n";
+		print 'Known Graph Templates: (id, name)' . PHP_EOL;
 	}
 
-	foreach ($templates as $id => $name) {
-		echo $id . "\t" . $name . "\n";
+	if ($templates !== false && cacti_sizeof($templates)) {
+		foreach ($templates as $id => $name) {
+			print $id . "\t" . $name . PHP_EOL;
+		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displayHosts($hosts, $quietMode = false) {
 	if (!$quietMode) {
-		echo "Known Devices: (id, hostname, template, description)\n";
+		print 'Known Devices: (id, hostname, template, description)' . PHP_EOL;
 	}
 
-	if (sizeof($hosts)) {
+	if ($hosts !== false && cacti_sizeof($hosts)) {
 		foreach($hosts as $host) {
-			echo $host['id'] . "\t" . $host['hostname'] . "\t" . $host['host_template_id'] . "\t" . $host['description'] . "\n";
+			print $host['id'] . "\t" . $host['hostname'] . "\t" . $host['host_template_id'] . "\t" . $host['description'] . PHP_EOL;
 		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
+	}
+}
+
+function displaySites($sites, $quietMode = false) {
+	if (!$quietMode) {
+		print 'Known Sites: (id, name)' . PHP_EOL;
+	}
+
+	if ($sites !== false && cacti_sizeof($sites)) {
+		foreach($sites as $site) {
+			print $site['id'] . "\t" . $site['name'] . PHP_EOL;
+		}
+	}
+
+	if (!$quietMode) {
+		print PHP_EOL;
 	}
 }
 
@@ -353,21 +468,23 @@ function displayTrees($quietMode = false) {
 	global $tree_sort_types;
 
 	if (!$quietMode) {
-		echo "Known Trees:\nid\tsort method\t\t\tname\n";
+		print 'Known Trees: (id, sort method, name)' . PHP_EOL;
 	}
 
-	$trees = db_fetch_assoc('SELECT id, sort_type, name FROM graph_tree ORDER BY id');
+	$trees = db_fetch_assoc('SELECT id, sort_type, name 
+		FROM graph_tree 
+		ORDER BY id');
 
-	if (sizeof($trees)) {
+	if (cacti_sizeof($trees)) {
 		foreach ($trees as $tree) {
-			echo $tree['id']."\t";
-			echo $tree_sort_types[$tree['sort_type']]."\t";
-			echo $tree['name']."\n";
+			print $tree['id'] . "\t";
+			print $tree_sort_types[$tree['sort_type']] . "\t";
+			print $tree['name'] . PHP_EOL;
 		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
@@ -376,8 +493,7 @@ function displayTreeNodes($tree_id, $nodeType = '', $parentNode = 0, $quietMode
 
 	if ($parentNode == 0) {
 		if (!$quietMode) {
-			echo "Known Tree Nodes:\n";
-			echo "type\tid\tparentid\ttitle\tattribs\n";
+			print 'Known Tree Nodes: (type, id, parentid, title, attribs)' . PHP_EOL;
 		}
 	}
 
@@ -390,7 +506,7 @@ function displayTreeNodes($tree_id, $nodeType = '', $parentNode = 0, $quietMode
 		AND parent = ?
 		ORDER BY position', array($tree_id, $parentNode));
 
-	if (sizeof($nodes)) {
+	if (cacti_sizeof($nodes)) {
 		foreach ($nodes as $node) {
 			/* taken from tree.php, funtion item_edit() */
 			$current_type = TREE_ITEM_TYPE_HEADER;
@@ -400,17 +516,17 @@ function displayTreeNodes($tree_id, $nodeType = '', $parentNode = 0, $quietMode
 			switch ($current_type) {
 				case TREE_ITEM_TYPE_HEADER:
 					if ($nodeType == '' || $nodeType == 'header') {
-						echo $tree_item_types[$current_type]."\t";
-						echo $node['id']."\t";
+						print $tree_item_types[$current_type]."\t";
+						print $node['id']."\t";
 						if ($parentNode == 0) {
-							echo "N/A\t";
+							print "N/A\t";
 						} else {
-							echo $parentNode . "\t";
+							print $parentNode . "\t";
 						}
 
-						echo $node['title'] . "\t";
-						echo $tree_sort_types[$node['sort_children_type']] . "\t";
-						echo "\n";
+						print $node['title'] . "\t";
+						print $tree_sort_types[$node['sort_children_type']] . "\t";
+						print PHP_EOL;
 					}
 
 					displayTreeNodes($tree_id, $nodeType, $node['id'], $quietMode);
@@ -418,12 +534,12 @@ function displayTreeNodes($tree_id, $nodeType = '', $parentNode = 0, $quietMode
 					break;
 				case TREE_ITEM_TYPE_GRAPH:
 					if ($nodeType == '' || $nodeType == 'graph') {
-						echo $tree_item_types[$current_type] . "\t";
-						echo $node['id'] . "\t";
+						print $tree_item_types[$current_type] . "\t";
+						print $node['id'] . "\t";
 						if ($parentNode == 0) {
-							echo "N/A\t";
+							print "N/A\t";
 						} else {
-							echo $parentNode . "\t";
+							print $parentNode . "\t";
 						}
 
 						/* fetch the title for that graph */
@@ -431,26 +547,26 @@ function displayTreeNodes($tree_id, $nodeType = '', $parentNode = 0, $quietMode
 							FROM graph_templates_graph AS gtg
 							WHERE gtg.local_graph_id = ?', array($node['local_graph_id']));
 
-						echo $graph_title . "\t";
-						echo "\n";
+						print $graph_title . "\t";
+						print PHP_EOL;
 					}
 
 					break;
 				case TREE_ITEM_TYPE_HOST:
 					if ($nodeType == '' || $nodeType == 'host') {
-						echo $tree_item_types[$current_type] . "\t";
-						echo $node['id'] . "\t";
+						print $tree_item_types[$current_type] . "\t";
+						print $node['id'] . "\t";
 						if ($parentNode == 0) {
-							echo "N/A\t";
+							print "N/A\t";
 						} else {
-							echo $parentNode . "\t";
+							print $parentNode . "\t";
 						}
 
 						$name = db_fetch_cell_prepared('SELECT hostname FROM host WHERE id = ?', array($node['host_id']));
 
-						echo $name . "\t";
-						echo $host_group_types[$node['host_grouping_type']] . "\t";
-						echo "\n";
+						print $name . "\t";
+						print $host_group_types[$node['host_grouping_type']] . "\t";
+						print PHP_EOL;
 					}
 				break;
 			}
@@ -459,36 +575,35 @@ function displayTreeNodes($tree_id, $nodeType = '', $parentNode = 0, $quietMode
 
 	if ($parentNode == 0) {
 		if (!$quietMode) {
-			echo "\n";
+			print PHP_EOL;
 		}
 	}
 }
 
 function displayRRAs($quietMode = false) {
 	if (!$quietMode) {
-		echo "Known RRAs:\nid\tsteps\trows\tname\n";
+		print 'Known RRAs: (id, steps, rows, name)' . PHP_EOL;
 	}
 
 	$rras = db_fetch_assoc('SELECT id, name, steps, `rows` FROM data_source_profiles_rra ORDER BY id');
 
-	if (sizeof($rras)) {
+	if (cacti_sizeof($rras)) {
 		foreach ($rras as $rra) {
-			echo $rra['id']."\t";
-			echo $rra['steps']."\t";
-			echo $rra['rows']."\t";
-			echo $rra['name']."\n";
+			print $rra['id']    . "\t";
+			print $rra['steps'] . "\t";
+			print $rra['rows']  . "\t";
+			print $rra['name']  . PHP_EOL;
 		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displayHostGraphs($host_id, $quietMode = false) {
-
 	if (!$quietMode) {
-		echo "Known Device Graphs: (id, name, template)\n";
+		print 'Known Device Graphs: (id, name, template)' . PHP_EOL;
 	}
 
 	$graphs = db_fetch_assoc_prepared('SELECT
@@ -501,37 +616,39 @@ function displayHostGraphs($host_id, $quietMode = false) {
 			AND graph_local.host_id = ?
 			ORDER BY graph_templates_graph.local_graph_id', array($host_id));
 
-	if (sizeof($graphs)) {
+	if (cacti_sizeof($graphs)) {
 		foreach ($graphs as $graph) {
-			echo $graph['id'] . "\t";
-			echo $graph['name'] . "\t";
-			echo $graph['template_name'] . "\t";
-			echo "\n";
+			print $graph['id'] . "\t";
+			print $graph['name'] . "\t";
+			print $graph['template_name'] . "\t";
+			print PHP_EOL;
 		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
 function displayUsers($quietMode = false) {
 	if (!$quietMode) {
-		echo "Known Users:\nid\tusername\tfull_name\n";
+		print 'Known Users: (id, username, full_name)'. PHP_EOL;
 	}
 
-	$groups = db_fetch_assoc('SELECT id, username, full_name FROM user_auth ORDER BY id');
+	$groups = db_fetch_assoc('SELECT id, username, full_name 
+		FROM user_auth 
+		ORDER BY id');
 
-	if (sizeof($groups)) {
+	if (cacti_sizeof($groups)) {
 		foreach ($groups as $group) {
-			echo $group['id']."\t";
-			echo $group['username']."\t";
-			echo $group['full_name']."\n";
+			print $group['id']        ."\t";
+			print $group['username']  ."\t";
+			print $group['full_name'] . PHP_EOL;
 		}
 	}
 
 	if (!$quietMode) {
-		echo "\n";
+		print PHP_EOL;
 	}
 }
 
