@@ -537,17 +537,21 @@ function db_add_column($table, $column, $log = true, $db_conn = false) {
 
 	if (isset($column['name']) && !in_array($column['name'], $columns)) {
 		$sql = 'ALTER TABLE `' . $table . '` ADD `' . $column['name'] . '`';
-		if (isset($column['type']))
+		if (isset($column['type'])) {
 			$sql .= ' ' . $column['type'];
+		}
 
-		if (isset($column['unsigned']))
+		if (isset($column['unsigned'])) {
 			$sql .= ' unsigned';
+		}
 
-		if (isset($column['NULL']) && $column['NULL'] === false)
+		if (isset($column['NULL']) && $column['NULL'] === false) {
 			$sql .= ' NOT NULL';
+		}
 
-		if (isset($column['NULL']) && $column['NULL'] === true && !isset($column['default']))
+		if (isset($column['NULL']) && $column['NULL'] === true && !isset($column['default'])) {
 			$sql .= ' default NULL';
+		}
 
 		if (isset($column['default'])) {
 			if (strtolower($column['type']) == 'timestamp' && $column['default'] === 'CURRENT_TIMESTAMP') {
@@ -557,17 +561,21 @@ function db_add_column($table, $column, $log = true, $db_conn = false) {
 			}
 		}
 
-		if (isset($column['on_update']))
+		if (isset($column['on_update'])) {
 			$sql .= ' ON UPDATE ' . $column['on_update'];
+		}
 
-		if (isset($column['auto_increment']))
+		if (isset($column['auto_increment'])) {
 			$sql .= ' auto_increment';
+		}
 
-		if (isset($column['comment']))
+		if (isset($column['comment'])) {
 			$sql .= " COMMENT '" . $column['comment'] . "'";
+		}
 
-		if (isset($column['after']))
+		if (isset($column['after'])) {
 			$sql .= ' AFTER ' . $column['after'];
+		}
 
 		return db_execute($sql, $log, $db_conn);
 	}
@@ -826,27 +834,45 @@ function db_update_table($table, $data, $removecolumns = false, $log = true, $db
 			// FIXME: Need to still check default value
 			$arr = db_fetch_row("SHOW columns FROM `$table` LIKE '" . $column['name'] . "'", $log, $db_conn);
 			if ($column['type'] != $arr['Type'] || (isset($column['NULL']) && ($column['NULL'] ? 'YES' : 'NO') != $arr['Null'])
-							    || (isset($column['auto_increment']) && ($column['auto_increment'] ? 'auto_increment' : '') != $arr['Extra'])) {
+			    || (isset($column['auto_increment']) && ($column['auto_increment'] ? 'auto_increment' : '') != $arr['Extra'])) {
 				$sql = 'ALTER TABLE `' . $table . '` CHANGE `' . $column['name'] . '` `' . $column['name'] . '`';
-				if (isset($column['type']))
+				if (isset($column['type'])) {
 					$sql .= ' ' . $column['type'];
-				if (isset($column['unsigned']))
-					$sql .= ' unsigned';
-				if (isset($column['NULL']) && $column['NULL'] == false)
-					$sql .= ' NOT NULL';
-				if (isset($column['NULL']) && $column['NULL'] == true && !isset($column['default']))
-					$sql .= ' default NULL';
-				if (isset($column['default']))
-					$sql .= ' default ' . (is_numeric($column['default']) ? $column['default'] : "'" . $column['default'] . "'");
-				if (isset($column['on_update']))
-					$sql .= ' ON UPDATE ' . $column['on_update'];
-				if (isset($column['auto_increment']))
-					$sql .= ' auto_increment';
-				if (isset($column['comment']))
-					$sql .= " COMMENT '" . $column['comment'] . "'";
+				}
 
-				if (!db_execute($sql, $log, $db_conn))
-				{
+				if (isset($column['unsigned'])) {
+					$sql .= ' unsigned';
+				}
+
+				if (isset($column['NULL']) && $column['NULL'] == false) {
+					$sql .= ' NOT NULL';
+				}
+
+				if (isset($column['NULL']) && $column['NULL'] == true && !isset($column['default'])) {
+					$sql .= ' default NULL';
+				}
+
+				if (isset($column['default'])) {
+					if (strtolower($column['type']) == 'timestamp' && $column['default'] === 'CURRENT_TIMESTAMP') {
+						$sql .= ' default CURRENT_TIMESTAMP';
+					} else {
+						$sql .= ' default ' . (is_numeric($column['default']) ? $column['default'] : "'" . $column['default'] . "'");
+					}
+				}
+
+				if (isset($column['on_update'])) {
+					$sql .= ' ON UPDATE ' . $column['on_update'];
+				}
+
+				if (isset($column['auto_increment'])) {
+					$sql .= ' auto_increment';
+				}
+
+				if (isset($column['comment'])) {
+					$sql .= " COMMENT '" . $column['comment'] . "'";
+				}
+
+				if (!db_execute($sql, $log, $db_conn)) {
 					return false;
 				}
 			}
@@ -1007,25 +1033,48 @@ function db_table_create($table, $data, $log = true, $db_conn = false) {
 		$sql = 'CREATE TABLE `' . $table . "` (\n";
 		foreach ($data['columns'] as $column) {
 			if (isset($column['name'])) {
-				if ($c > 0)
+				if ($c > 0) {
 					$sql .= ",\n";
+				}
+
 				$sql .= '`' . $column['name'] . '`';
-				if (isset($column['type']))
+
+				if (isset($column['type'])) {
 					$sql .= ' ' . $column['type'];
-				if (isset($column['unsigned']))
+				}
+
+				if (isset($column['unsigned'])) {
 					$sql .= ' unsigned';
-				if (isset($column['NULL']) && $column['NULL'] == false)
+				}
+
+				if (isset($column['NULL']) && $column['NULL'] == false) {
 					$sql .= ' NOT NULL';
-				if (isset($column['NULL']) && $column['NULL'] == true && !isset($column['default']))
+				}
+
+				if (isset($column['NULL']) && $column['NULL'] == true && !isset($column['default'])) {
 					$sql .= ' default NULL';
-				if (isset($column['default']))
-					$sql .= ' default ' . (is_numeric($column['default']) ? $column['default'] : "'" . $column['default'] . "'");
-				if (isset($column['on_update']))
+				}
+
+				if (isset($column['default'])) {
+					if (strtolower($column['type']) == 'timestamp' && $column['default'] === 'CURRENT_TIMESTAMP') {
+						$sql .= ' default CURRENT_TIMESTAMP';
+					} else {
+						$sql .= ' default ' . (is_numeric($column['default']) ? $column['default'] : "'" . $column['default'] . "'");
+					}
+				}
+
+				if (isset($column['on_update'])) {
 					$sql .= ' ON UPDATE ' . $column['on_update'];
-				if (isset($column['comment']))
+				}
+
+				if (isset($column['comment'])) {
 					$sql .= " COMMENT '" . $column['comment'] . "'";
-				if (isset($column['auto_increment']))
+				}
+
+				if (isset($column['auto_increment'])) {
 					$sql .= ' auto_increment';
+				}
+
 				$c++;
 			}
 		}
