@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -47,6 +47,11 @@ switch (get_request_var('action')) {
 
 		header('Location: reports_user.php?action=edit&tab=' . get_request_var('tab') . '&id=' . get_request_var('id'));
 		break;
+	case 'ajax_dnd':
+		reports_item_dnd();
+
+		header('Location: reports_admin.php?action=edit&header=false&tab=items&id=' . get_request_var('id'));
+		break;
 	case 'actions':
 		reports_form_actions();
 		break;
