@@ -1,17 +1,13 @@
 <?php
 
-$no_http_headers = true;
-
 /* do NOT run this script through a web browser */
-if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die('<br><strong>This script is only meant to run at the command line.</strong>');
-}
+$no_http_headers = true;
 
 /* display no errors */
 error_reporting(0);
 
 if (!isset($called_by_script_server)) {
-	include_once(dirname(__FILE__) . '/../include/global.php');
+	include_once(dirname(__FILE__) . '/../include/cli_check.php');
 
 	print call_user_func('ss_sql');
 }
