@@ -904,7 +904,7 @@ function vdef($refresh = true) {
             form_end_row();
         }
     } else {
-        print "<tr class='tableRow'><td colspan='4'><em>" . __('No VDEFs') . "</em></td></tr>\n";
+        print "<tr class='tableRow'><td colspan='" . (cacti_sizeof($display_text)+1) . "'><em>" . __('No VDEFs') . "</em></td></tr>\n";
     }
 
     html_end_box(false);
